Glossary
--------

vector:
   A named collection of values, where all the values have the same
   type, and each value is identified by an index.

element:
   One of the values in a vector. The ``[]`` operator selects elements
   of a vector.

index:
   An integer variable or value used to indicate an element of a vector.

constructor:
   A special function that creates a new object and initializes its
   instance variables.

deterministic:
   A program that does the same thing every time it is run.

pseudorandom:
   A sequence of numbers that appear to be random, but which are
   actually the product of a deterministic computation.

seed:
   A value used to initialize a random number sequence. Using the same
   seed should yield the same sequence of values.

bottom-up design:
   A method of program development that starts by writing small, useful
   functions and then assembling them into larger solutions.

histogram:
   A vector of integers where each integer counts the number of values
   that fall into a certain range.

.. dragndrop:: glossary_1
    :feedback: Try again!
    :match_1: vector|||A named collection of values, where all the values have the same type, and each value is identified by an index.
    :match_2: element|||One of the values in a vector.
    :match_3: index|||An integer variable or value used to indicate an element of a vector.
    
    Match the vocabulary word with its definition.

.. dragndrop:: glossary_2
    :match_1: constructor|||A special function that creates a new object and initializes its instance variables.
    :match_2: pseudorandom|||A sequence of numbers that appear to be random, but which are actually the product of a deterministic computation.
    :match_3: seed|||A value used to initialize a random number sequence.

    Match the vocabulary word with its definition.

.. dragndrop:: glossary_3
    :feedback: Try again!
    :match_1: deterministic|||A program that does the same thing every time it is run.
    :match_2: bottom-up design|||A method of program development that starts by writing small, useful functions and then assembling them into larger solutions.
    :match_3: histogram|||A vector of integers where each integer counts the number of values that fall into a certain range.

    Match the vocabulary word with its definition.